import { d3 } from '../d3-bundle';
export class ChartService {
    constructor() {
        this.margin = { top: 20, right: 30, bottom: 30, left: 40 };
    }
    line(svg, x, y, dataConfig) {
        const valueLine = d3.line()
            .x((d) => x(d.date))
            .y((da) => y(da.value));
        svg.append('path')
            .data([dataConfig.data])
            .attr('class', 'line')
            .attr('d', valueLine);
    }
    xAxis(svg, dataConfig) {
        const x = d3.scaleTime()
            .domain(d3.extent(dataConfig.data, (d) => d.date))
            .range([this.margin.left, dataConfig.config.dims.width - this.margin.right]);
        svg.append('g')
            .attr('transform', `translate(0,${dataConfig.config.dims.height - this.margin.bottom})`)
            .call(d3.axisBottom(x).ticks(dataConfig.config.dims.width / 80).tickSizeOuter(0));
        return x;
    }
    yAxis(svg, dataConfig) {
        const y = d3.scaleLinear()
            .domain([0, d3.max(dataConfig.data, (d) => d.value)]).nice()
            .range([dataConfig.config.dims.height - this.margin.bottom, this.margin.top]);
        svg.append('g')
            .attr('transform', `translate(${this.margin.left},0)`)
            .call(d3.axisLeft(y));
        return y;
    }
    createSVG(dims) {
        const svg = d3.create('svg');
        svg
            .attr('width', dims.width + this.margin.left + this.margin.right)
            .attr('height', dims.height + this.margin.top + this.margin.bottom)
            .append('g')
            .attr('transform', `translate(${this.margin.left}, ${this.margin.right})`);
        return svg;
    }
    formatData(dataConfig) {
        const formatted = dataConfig.data.map(d => {
            return {
                value: d.value,
                date: new Date(d.date)
            };
        });
        return formatted;
    }
}
