import { h } from '../anjuna-charts.core.js';

import { a as d3 } from './chunk-1ad07b08.js';

class ChartService {
    constructor() {
        this.margin = { top: 20, right: 30, bottom: 30, left: 40 };
    }
    line(svg, x, y, dataConfig) {
        const valueLine = d3.line()
            .x((d) => x(d.date))
            .y((da) => y(da.value));
        svg.append('path')
            .data([dataConfig.data])
            .attr('class', 'line')
            .attr('d', valueLine);
    }
    xAxis(svg, dataConfig) {
        const x = d3.scaleTime()
            .domain(d3.extent(dataConfig.data, (d) => d.date))
            .range([this.margin.left, dataConfig.config.dims.width - this.margin.right]);
        svg.append('g')
            .attr('transform', `translate(0,${dataConfig.config.dims.height - this.margin.bottom})`)
            .call(d3.axisBottom(x).ticks(dataConfig.config.dims.width / 80).tickSizeOuter(0));
        return x;
    }
    yAxis(svg, dataConfig) {
        const y = d3.scaleLinear()
            .domain([0, d3.max(dataConfig.data, (d) => d.value)]).nice()
            .range([dataConfig.config.dims.height - this.margin.bottom, this.margin.top]);
        svg.append('g')
            .attr('transform', `translate(${this.margin.left},0)`)
            .call(d3.axisLeft(y));
        return y;
    }
    createSVG(dims) {
        const svg = d3.create('svg');
        svg
            .attr('width', dims.width + this.margin.left + this.margin.right)
            .attr('height', dims.height + this.margin.top + this.margin.bottom)
            .append('g')
            .attr('transform', `translate(${this.margin.left}, ${this.margin.right})`);
        return svg;
    }
    formatData(dataConfig) {
        const formatted = dataConfig.data.map(d => {
            return {
                value: d.value,
                date: new Date(d.date)
            };
        });
        return formatted;
    }
}

class Sparkline {
    constructor() {
        this.chartService = new ChartService();
    }
    dataConfigHandler(newValue, oldValue) {
        console.log('firing', newValue, oldValue);
        if (newValue !== oldValue) {
            this.chart = this.create();
        }
    }
    componentDidLoad() {
        this.chart = this.create();
    }
    appendSVG(svg) {
        while (this.chartContainer.firstChild) {
            this.chartContainer.removeChild(this.chartContainer.firstChild);
        }
        this.chartContainer.appendChild(svg.node());
    }
    create() {
        console.log('dataConfig', this.dataConfig);
        this.dataConfig.data = this.chartService.formatData(this.dataConfig);
        this.dataConfig.config.dims = this.getDims();
        const svg = this.chartService.createSVG(this.dataConfig);
        const x = this.chartService.xAxis(svg, this.dataConfig);
        const y = this.chartService.yAxis(svg, this.dataConfig);
        this.chartService.line(svg, x, y, this.dataConfig);
        this.appendSVG(svg);
        return svg;
    }
    getDims() {
        const { height, width } = this.chartContainer.getBoundingClientRect();
        return { height, width };
    }
    render() {
        return (h("div", { class: "chart-container", ref: (el) => this.chartContainer = el }));
    }
    static get is() { return "anj-sparkline"; }
    static get properties() { return {
        "dataConfig": {
            "type": "Any",
            "attr": "data-config",
            "mutable": true,
            "watchCallbacks": ["dataConfigHandler"]
        }
    }; }
    static get style() { return ".anj-chart .line,anj-sparkline .line{fill:none;stroke:#4682b4;stroke-width:2px}anj-sparkline .chart-container{height:500px;width:500px}"; }
}

export { Sparkline as AnjSparkline };
